import { usePageData } from '@vuepress/client';
import { useClipboard, useEventListener } from '@vueuse/core';
import { defineComponent, nextTick, onMounted, watch, ref } from 'vue';
import { copiedText, copyText, selector } from '../define.js';
export const CodeCopy = defineComponent({
    name: 'CodeCopy',
    setup(props, ctx) {
        const page = usePageData();
        const { copy } = useClipboard({ legacy: true });
        const timeId = ref(0);
        const copyHandler = async (preContent, el) => {
            let { innerText: text = '' } = preContent;
            text = text.replace(/^ *(\$|>) /gm, '');
            try {
                await copy(text);
                el.innerText = copiedText;
                timeId.value = window.setTimeout(() => {
                    el.innerText = copyText;
                }, 500);
            }
            catch (error) {
                console.log('copy error', error);
            }
        };
        const insertButton = async () => {
            await nextTick();
            const allCodeHtml = document.querySelectorAll(selector);
            for (let i = 0; i < allCodeHtml.length; i++) {
                const parent = allCodeHtml[i];
                // 如果有选项提出
                if (parent.querySelector('.code-copy-btn')) {
                    continue;
                }
                const copyHtml = document.createElement('span');
                copyHtml.className = 'code-copy-btn';
                copyHtml.innerText = copyText;
                parent.appendChild(copyHtml);
            }
        };
        onMounted(() => {
            insertButton();
            useEventListener('click', (event) => {
                const el = event.target;
                if (el.matches('div[class*="language-"] > span.code-copy-btn')) {
                    // 点击复制按钮
                    const parentElement = el.parentElement;
                    const preHtml = (parentElement?.querySelector('pre[class*="language-"]'));
                    if (timeId.value) {
                        clearTimeout(timeId.value);
                    }
                    if (el.innerText === copiedText) {
                        // 如果当前是已复制状态
                        return;
                    }
                    if (preHtml) {
                        copyHandler(preHtml, el);
                    }
                }
            });
        });
        watch(() => page.value.path, val => {
            insertButton();
        });
    }
});
export default CodeCopy;
